==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Slider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SliderBase } from "./SliderBase";
import { markType } from "igniteui-react-core";
import { NumberEventArgs } from "./NumberEventArgs";
/**
 * @hidden
 */
export let Slider = /*@__PURE__*/ (() => {
    class Slider extends SliderBase {
        constructor() {
            super(...arguments);
            this.input = null;
            this.change = null;
        }
        get aa() {
            let ret_ = this.e.m("value");
            return ret_;
        }
        set aa(a) {
            let value_ = a;
            this.e.u("value", value_);
        }
        get ab() {
            let ret_ = this.e.m("ariaLabel");
            return ret_;
        }
        set ab(a) {
            let value_ = a;
            this.e.u("ariaLabel", value_);
        }
        inputChanged() {
            if (this.input != null) {
                this.e.q("input", (a) => this.input(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.t("input");
            }
        }
        changeChanged() {
            if (this.change != null) {
                this.e.q("change", (a) => this.change(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.t("change");
            }
        }
        af(a) {
            this.nativeElement.stepUp(this.e.h(a));
        }
        ae(a) {
            this.nativeElement.stepDown(this.e.h(a));
        }
    }
    Slider.$t = /*@__PURE__*/ markType(Slider, 'Slider', SliderBase.$);
    return Slider;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Slider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SliderBase } from "./SliderBase";
import { markType } from "igniteui-react-core";
import { NumberEventArgs } from "./NumberEventArgs";
/**
 * @hidden
 */
export let Slider = /*@__PURE__*/ (() => {
    class Slider extends SliderBase {
        constructor() {
            super(...arguments);
            this.input = null;
            this.change = null;
        }
        get aa() {
            let ret_ = this.e.n("value");
            return ret_;
        }
        set aa(a) {
            let value_ = a;
            this.e.v("value", value_);
        }
        get ab() {
            let ret_ = this.e.n("ariaLabel");
            return ret_;
        }
        set ab(a) {
            let value_ = a;
            this.e.v("ariaLabel", value_);
        }
        inputChanged() {
            if (this.input != null) {
                this.e.r("input", (a) => this.input(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.u("input");
            }
        }
        changeChanged() {
            if (this.change != null) {
                this.e.r("change", (a) => this.change(this, NumberEventArgs.a(a)));
            }
            else {
                this.e.u("change");
            }
        }
        af(a) {
            this.nativeElement.stepUp(this.e.i(a));
        }
        ae(a) {
            this.nativeElement.stepDown(this.e.i(a));
        }
    }
    Slider.$t = /*@__PURE__*/ markType(Slider, 'Slider', SliderBase.$);
    return Slider;
})();
